# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .client_facing_marker_complete import ClientFacingMarkerComplete


class GetMarkersResponse(UniversalBaseModel):
    markers: typing.List[ClientFacingMarkerComplete]
    total: typing.Optional[int] = None
    page: typing.Optional[int] = None
    size: typing.Optional[int] = None
    pages: typing.Optional[int] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
